@@ -5,19 +5,13 @@ use vars qw($VERSION @EXPORT_OK);
 use Exporter;
 use base qw(Exporter);
 
-$VERSION = '1.800.2';
+$VERSION = '1.803';
 
 @EXPORT_OK = qw(
   FORMAT_UNDEF FORMAT_ASN1 FORMAT_TEXT FORMAT_PEM FORMAT_NETSCAPE
   FORMAT_PKCS12 FORMAT_SMIME FORMAT_ENGINE FORMAT_IISSGC OPENSSL_VERSION_NUMBER
 );
 
-sub Crypt::OpenSSL::X509::bit_length {
-  my $x509 = shift;
-
-  return length($x509->modulus) * 4; # each character is one hex digit = 4 bits
-}
-
 sub Crypt::OpenSSL::X509::has_extension_oid {
   my $x509 = shift;
   my $oid  = shift;
@@ -126,7 +120,7 @@ Crypt::OpenSSL::X509 - Perl extension to OpenSSL's X509 API.
   print $x509->exponent() . "\n";
   print $x509->fingerprint_sha1() . "\n";
   print $x509->fingerprint_md5() . "\n";
-  print $x509->as_string(Crypt::OpenSSL::X509::FORMAT_TEXT) . "\n";
+  print $x509->as_string() . "\n";
 
   my $x509 = Crypt::OpenSSL::X509->new_from_string(
     $der_encoded_data, Crypt::OpenSSL::X509::FORMAT_ASN1
@@ -134,9 +128,9 @@ Crypt::OpenSSL::X509 - Perl extension to OpenSSL's X509 API.
 
   # given a time offset of $seconds, will the certificate be valid?
   if ($x509->checkend($seconds)) {
-    # cert is ok at $seconds offset
-  } else {
     # cert is expired at $seconds offset
+  } else {
+    # cert is ok at $seconds offset
   }
 
   my $exts = $x509->extensions_by_oid();
@@ -229,6 +223,14 @@ Certificate version as a string.
 
 Signature algorithm name as a string.
 
+=item key_alg_name
+
+Public key algorithm name as a string.
+
+=item curve
+
+Name of the EC curve used in the public key.
+
 =back
 
 =head2 X509 METHODS
@@ -251,7 +253,7 @@ Return the certificate as a string in the specified format. C<FORMAT> can be one
 
 =item modulus ( )
 
-Return the modulus for an RSA public key as a string of hex digits. For DSA, return the public key. Other algorithms are not supported.
+Return the modulus for an RSA public key as a string of hex digits. For DSA and EC return the public key. Other algorithms are not supported.
 
 =item bit_length ( )
 
@@ -265,11 +267,11 @@ Return the specified message digest for the certificate.
 
 =item checkend( OFFSET )
 
-Given an offset in seconds, will the certificate be expired?
+Given an offset in seconds, will the certificate be expired? Returns True if the certificate will be expired. False otherwise.
 
 =item pubkey ( )
 
-Return the RSA or DSA public key.
+Return the RSA, DSA, or EC public key.
 
 =item num_extensions ( )
 
@@ -281,7 +283,9 @@ Return the Extension specified by the integer C<INDEX>.
 Methods for handling Extension objects are given below.
 
 =item extensions_by_oid ( )
+
 =item extensions_by_name ( )
+
 =item extensions_by_long_name ( )
 
 Return a hash of Extensions indexed by OID or name.
@@ -407,7 +411,7 @@ Daniel Kahn Gillmor E<lt>dkg@fifthhorseman.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2011 by Dan Sully
+Copyright 2004-2013 by Dan Sully
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
